Class: Fontist::FontStyle

Inherits:
Lutaml::Model::Serializable
  • Object
show all
Defined in:
lib/fontist/font_style.rb

Overview

FontStyle - v5 font style with format metadata for multi-format support

Instance Method Summary collapse

Instance Method Details

#variable_font?Boolean

Helper to check if this is a variable font Returns false if not set, true only if explicitly set to true

Returns:

  • (Boolean)


50
51
52
# File 'lib/fontist/font_style.rb', line 50

def variable_font?
  variable_font == true
end