Module: Fontist::Import::Google::FormulaBuilder
- Defined in:
- lib/fontist/import/google/formula_builder.rb
Overview
Factory module for creating formula builders
Class Method Summary collapse
-
.build(family, version:, **kwargs) ⇒ Object
Build a formula using the appropriate builder for the version.
-
.for_version(version) ⇒ Object
Get the appropriate builder class for a version.
Class Method Details
.build(family, version:, **kwargs) ⇒ Object
Build a formula using the appropriate builder for the version
18 19 20 21 22 |
# File 'lib/fontist/import/google/formula_builder.rb', line 18 def self.build(family, version:, **kwargs) builder_class = for_version(version) builder = builder_class.new(family, **kwargs) builder.build end |
.for_version(version) ⇒ Object
Get the appropriate builder class for a version
13 14 15 |
# File 'lib/fontist/import/google/formula_builder.rb', line 13 def self.for_version(version) FormulaBuilders::BaseFormulaBuilder.for_version(version) end |