Class: Fontist::Import::Google::MetadataAdapter
- Inherits:
-
Object
- Object
- Fontist::Import::Google::MetadataAdapter
- Defined in:
- lib/fontist/import/google/metadata_adapter.rb
Overview
Adapts unibuf’s generic Message model to our domain Metadata model
This adapter bridges between the generic protocol buffer parser (unibuf) and our rich domain model (Models::Metadata), extracting and transforming all fields according to our business requirements.
Defined Under Namespace
Classes: FieldWrapper, MessageWrapper, ValueWrapper
Class Method Summary collapse
-
.adapt(unibuf_message) ⇒ Models::Metadata
Adapt unibuf message to Metadata model.
Class Method Details
.adapt(unibuf_message) ⇒ Models::Metadata
Adapt unibuf message to Metadata model
23 24 25 26 |
# File 'lib/fontist/import/google/metadata_adapter.rb', line 23 def self.adapt() hash = () Models::Metadata.new(hash) end |