Class: Fontist::Import::Macos

Inherits:
Object
  • Object
show all
Defined in:
lib/fontist/import/macos.rb

Constant Summary collapse

FONT_XML =

rubocop:disable Layout/LineLength

"/System/Library/AssetsV2/com_apple_MobileAsset_Font6/com_apple_MobileAsset_Font6.xml".freeze
DESCRIPTION =
"Fonts included with macOS %<name>s".freeze
INSTRUCTIONS =
<<~INSTRUCTIONS.freeze
  To download and enable any of these fonts:

  1. Open Font Book, which is in your Applications folder.
  2. Select All Fonts in the sidebar, or use the Search field to find the font that you want to download. Fonts that are not already downloaded appear dimmed in the list of fonts.
  3. Select the dimmed font and choose Edit > Download, or Control-click it and choose Download from the pop-up menu.
INSTRUCTIONS

Instance Method Summary collapse

Constructor Details

#initialize(options = {}) ⇒ Macos

Returns a new instance of Macos.



22
23
24
# File 'lib/fontist/import/macos.rb', line 22

def initialize(options = {})
  @options = options
end

Instance Method Details

#callObject



26
27
28
29
30
31
32
33
# File 'lib/fontist/import/macos.rb', line 26

def call
  downloadable_fonts = fetch_fonts_list
  links = fetch_links(downloadable_fonts)
  archives = download(links)
  store_in_dir(archives) do |dir|
    create_formula(dir)
  end
end